@@ -469,7 +469,7 @@
 
                 renderPaginationItem.call(this, pagination, "first", "&laquo;", "first")
                     ._bgEnableAria(current > 1);
-                renderPaginationItem.call(this, pagination, "prev", "&lt;", "prev")
+                renderPaginationItem.call(this, pagination, "prev", "&lsaquo;", "prev")
                     ._bgEnableAria(current > 1);
 
                 for (var i = 0; i < count; i++)
@@ -485,7 +485,7 @@
                         ._bgEnableAria(false)._bgSelectAria();
                 }
 
-                renderPaginationItem.call(this, pagination, "next", "&gt;", "next")
+                renderPaginationItem.call(this, pagination, "next", "&rsaquo;", "next")
                     ._bgEnableAria(totalPages > current);
                 renderPaginationItem.call(this, pagination, "last", "&raquo;", "last")
                     ._bgEnableAria(totalPages > current);
@@ -659,7 +659,7 @@
         var that = this,
             selectBoxSelector = getCssSelector(this.options.css.selectBox);
 
-        if (this.selection)
+        if (this.selection && !this.options.rowSelect)
         {
             tbody.off("click" + namespace, selectBoxSelector)
                 .on("click" + namespace, selectBoxSelector, function(e)
